@@ -1,5 +1,3 @@
-from codepack.interface.interface import Interface
-from codepack.interface.sql_interface import SQLInterface
 from codepack.interface.mongodb import MongoDB
 from codepack.interface.mysql import MySQL
 from codepack.interface.mssql import MSSQL
