@@ -1,5 +1,5 @@
-from docker import DockerClient
-from codepack.interface import Interface
+from codepack.interface.interface import Interface
+import docker
 
 
 class Docker(Interface):
@@ -8,7 +8,7 @@ class Docker(Interface):
         self.connect(*args, **kwargs)
 
     def connect(self, *args, **kwargs):
-        self.session = DockerClient(*args, **self.config, **kwargs)
+        self.session = docker.DockerClient(*args, **self.config, **kwargs)
         self._closed = False
         return self.session
 
