@@ -1,6 +1,6 @@
-from collections.abc import Callable
 from codepack.service.service import Service
-from codepack.callback import Callback
+from codepack.callback.callback import Callback
+from collections.abc import Callable
 
 
 class CallbackService(Service):
