@@ -1,5 +1,3 @@
-from codepack.storage.storable import Storable
-from codepack.storage.storage import Storage
 from codepack.storage.memory_storage import MemoryStorage
 from codepack.storage.file_storage import FileStorage
 from codepack.storage.mongo_storage import MongoStorage
